==> apache-karaf-decanter-2.10.0-src.tar.gz: apache-karaf-decanter-2.10.0/collector/prometheus/src/test/java/org/apache/karaf/decanter/collector/prometheus/PrometheusCollectorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.decanter.collector.prometheus;

import org.junit.Assert;
import org.junit.Test;
import org.osgi.service.event.Event;
import org.osgi.service.event.EventAdmin;

import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;

public class PrometheusCollectorTest {

    @Test
    public void test() throws Exception {
        MockDispatcher dispatcher = new MockDispatcher();
        PrometheusCollector prometheusCollector = new PrometheusCollector();
        prometheusCollector.setDispatcher(dispatcher);
        Hashtable<String, Object> configuration = new Hashtable<>();
        configuration.put("prometheus.url", "file:target/test-classes/sample.txt");
        prometheusCollector.activate(configuration);

        prometheusCollector.run();

        Assert.assertEquals(1, dispatcher.postedEvents.size());

        Assert.assertEquals(0.0, dispatcher.postedEvents.get(0).getProperty("Test1"));
        Assert.assertEquals(8.0, dispatcher.postedEvents.get(0).getProperty("Test2"));
        Assert.assertEquals("prometheus", dispatcher.postedEvents.get(0).getProperty("type"));
    }

    class MockDispatcher implements EventAdmin {

        public List<Event> postedEvents = new ArrayList<>();
        public List<Event> sentEvents = new ArrayList<>();

        @Override
        public void postEvent(Event event) {
            postedEvents.add(event);
        }

        @Override
        public void sendEvent(Event event) {
            sentEvents.add(event);
        }
    }

}

==> apache-karaf-decanter-2.11.0-src.tar.gz: apache-karaf-decanter-2.11.0/collector/prometheus/src/test/java/org/apache/karaf/decanter/collector/prometheus/PrometheusCollectorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.decanter.collector.prometheus;

import org.junit.Assert;
import org.junit.Test;
import org.osgi.service.event.Event;
import org.osgi.service.event.EventAdmin;

import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;

public class PrometheusCollectorTest {

    @Test
    public void test() throws Exception {
        MockDispatcher dispatcher = new MockDispatcher();
        PrometheusCollector prometheusCollector = new PrometheusCollector();
        prometheusCollector.setDispatcher(dispatcher);
        Hashtable<String, Object> configuration = new Hashtable<>();
        configuration.put("prometheus.url", "file:target/test-classes/sample.txt");
        prometheusCollector.activate(configuration);

        prometheusCollector.run();

        Assert.assertEquals(5, dispatcher.postedEvents.size());

        Assert.assertEquals(0.0, dispatcher.postedEvents.get(0).getProperty("Test1"));
        Assert.assertEquals("prometheus", dispatcher.postedEvents.get(0).getProperty("type"));

        Assert.assertEquals(8.0, dispatcher.postedEvents.get(1).getProperty("Test2"));
        Assert.assertEquals("prometheus", dispatcher.postedEvents.get(1).getProperty("type"));

        Assert.assertEquals(1.0, dispatcher.postedEvents.get(2).getProperty("request_time_total_seconds"));
        Assert.assertEquals("/send", dispatcher.postedEvents.get(2).getProperty("endpoint"));
        Assert.assertEquals("prometheus", dispatcher.postedEvents.get(2).getProperty("type"));

        Assert.assertEquals(2.2561752E7, dispatcher.postedEvents.get(3).getProperty("memoryPool_usage_bytes"));
        Assert.assertEquals("Compressed Class Space", dispatcher.postedEvents.get(3).getProperty("name"));
        Assert.assertEquals("prometheus", dispatcher.postedEvents.get(3).getProperty("type"));

        Assert.assertEquals(1.2582912E7, dispatcher.postedEvents.get(4).getProperty("memoryPool_usage_bytes"));
        Assert.assertEquals("G1 Eden Space", dispatcher.postedEvents.get(4).getProperty("name"));
        Assert.assertEquals("prometheus", dispatcher.postedEvents.get(4).getProperty("type"));
    }

    class MockDispatcher implements EventAdmin {

        public List<Event> postedEvents = new ArrayList<>();
        public List<Event> sentEvents = new ArrayList<>();

        @Override
        public void postEvent(Event event) {
            postedEvents.add(event);
        }

        @Override
        public void sendEvent(Event event) {
            sentEvents.add(event);
        }
    }

}
